==> scala-k8s-objects_sjs1_2.12-0.3.0-sources.jar: io/k8s/kube-aggregator/pkg/apis/apiregistration/v1/ServiceReference.scala <==
package io.k8s.kube_aggregator.pkg.apis.apiregistration.v1

import dev.hnaderi.k8s.utils._

/** ServiceReference holds a reference to Service.legacy.k8s.io */
final case class ServiceReference(
  name : Option[String] = None,
  namespace : Option[String] = None,
  port : Option[Int] = None
) {

  /** Returns a new data with name set to new value */
  def withName(value: String) : ServiceReference = copy(name = Some(value))
  /** if name has a value, transforms to the result of function*/
  def mapName(f: String => String) : ServiceReference = copy(name = name.map(f))

  /** Returns a new data with namespace set to new value */
  def withNamespace(value: String) : ServiceReference = copy(namespace = Some(value))
  /** if namespace has a value, transforms to the result of function*/
  def mapNamespace(f: String => String) : ServiceReference = copy(namespace = namespace.map(f))

  /** Returns a new data with port set to new value */
  def withPort(value: Int) : ServiceReference = copy(port = Some(value))
  /** if port has a value, transforms to the result of function*/
  def mapPort(f: Int => Int) : ServiceReference = copy(port = port.map(f))
}

object ServiceReference {

    implicit def encoder[T](implicit builder : Builder[T]) : Encoder[io.k8s.kube_aggregator.pkg.apis.apiregistration.v1.ServiceReference, T] = new Encoder[io.k8s.kube_aggregator.pkg.apis.apiregistration.v1.ServiceReference, T] {
        def apply(o: io.k8s.kube_aggregator.pkg.apis.apiregistration.v1.ServiceReference) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("name", o.name)
            .write("namespace", o.namespace)
            .write("port", o.port)
            .build
        }
    }

    implicit def decoderOf[T : Reader] : Decoder[T, ServiceReference] = new Decoder[T, ServiceReference] {
      def apply(t: T): Either[String, ServiceReference] = for {
          obj <- ObjectReader(t)
          name <- obj.readOpt[String]("name")
          namespace <- obj.readOpt[String]("namespace")
          port <- obj.readOpt[Int]("port")
      } yield ServiceReference (
          name = name,
          namespace = namespace,
          port = port
        )
    }
}

==> scala-k8s-objects_sjs1_2.13-0.4.0-sources.jar: io/k8s/kube-aggregator/pkg/apis/apiregistration/v1/ServiceReference.scala <==
package io.k8s.kube_aggregator.pkg.apis.apiregistration.v1

import dev.hnaderi.k8s.utils._

/** ServiceReference holds a reference to Service.legacy.k8s.io */
final case class ServiceReference(
  name : Option[String] = None,
  namespace : Option[String] = None,
  port : Option[Int] = None
) {

  /** Returns a new data with name set to new value */
  def withName(value: String) : ServiceReference = copy(name = Some(value))
  /** if name has a value, transforms to the result of function*/
  def mapName(f: String => String) : ServiceReference = copy(name = name.map(f))

  /** Returns a new data with namespace set to new value */
  def withNamespace(value: String) : ServiceReference = copy(namespace = Some(value))
  /** if namespace has a value, transforms to the result of function*/
  def mapNamespace(f: String => String) : ServiceReference = copy(namespace = namespace.map(f))

  /** Returns a new data with port set to new value */
  def withPort(value: Int) : ServiceReference = copy(port = Some(value))
  /** if port has a value, transforms to the result of function*/
  def mapPort(f: Int => Int) : ServiceReference = copy(port = port.map(f))
}

object ServiceReference {

    implicit val encoder : Encoder[io.k8s.kube_aggregator.pkg.apis.apiregistration.v1.ServiceReference] = new Encoder[io.k8s.kube_aggregator.pkg.apis.apiregistration.v1.ServiceReference] {
        def apply[T : Builder](o: io.k8s.kube_aggregator.pkg.apis.apiregistration.v1.ServiceReference) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("name", o.name)
            .write("namespace", o.namespace)
            .write("port", o.port)
            .build
        }
    }

    implicit val decoder: Decoder[ServiceReference] = new Decoder[ServiceReference] {
      def apply[T : Reader](t: T): Either[String, ServiceReference] = for {
          obj <- ObjectReader(t)
          name <- obj.readOpt[String]("name")
          namespace <- obj.readOpt[String]("namespace")
          port <- obj.readOpt[Int]("port")
      } yield ServiceReference (
          name = name,
          namespace = namespace,
          port = port
        )
    }
}
